@@ -172,11 +172,12 @@ def bond_functions_risks(qlbond: ql.QuantLib.FixedRateBond,
     return risks
 
 
-def z_spread(fixbond:ql.QuantLib.FixedRateBond, 
+def z_spread(clean_price: float,
+            fixbond:ql.QuantLib.FixedRateBond, 
             yieldcurve: ql.QuantLib.TermStructure,
             setting: BondSetting):
     return ql.BondFunctions.zSpread(fixbond, 
-            109.0555, yieldcurve, 
+            clean_price, yieldcurve, 
             ql_day_count[setting.day_count], 
             ql.Compounded, 
             ql_frequency[setting.frequency])
\ No newline at end of file
