@@ -125,10 +125,67 @@ def calc_curve(value_date: str,
     return zero_set, df_set
     
 
+def calc_qlzerorate(from_date: str, to_date: str, day_count: DayCount,
+                    t_structure: ql.QuantLib.TermStructure, compounding,
+                    frequency: Frequency):
+
+    fdate = datestr_to_qldate(from_date)
+    tdate = datestr_to_qldate(to_date)
+    ql_dc = ql_day_count[day_count]
+    yrs = ql_dc.yearFraction(fdate, tdate)
+    zero_rate = t_structure.zeroRate(yrs, 
+                                    ql_compounding[compounding], 
+                                    ql_frequency[frequency])
+    return zero_rate
+
+
+def calc_equiv_rate(from_date: str, 
+                    to_date: str,
+                    qlrate: ql.QuantLib.InterestRate,
+                    day_count: DayCount,
+                    compounding,
+                    frequency: Frequency):
+    fdate = datestr_to_qldate(from_date)
+    tdate = datestr_to_qldate(to_date)
+    rate = qlrate.equivalentRate(ql_day_count[day_count],
+                                ql_compounding[compounding],
+                                ql_frequency[frequency],
+                                fdate,
+                                tdate).rate()
+    return rate
+
     
+def ql_spread_handle(value_date: str, 
+                    t_structure: ql.QuantLib.TermStructure, 
+                    spreads: List[Rate],
+                    calendar = None):
+    vdate = datestr_to_qldate(value_date)
+    ts_handle = ql.YieldTermStructureHandle(t_structure)
     
-    
-    
+    if calendar == None:
+        qlcalendar = ql.WeekendsOnly()
+    else:
+        qlcalendar = calendar
+
+    spread_handles = []
+    spread_dates = []
+    spread_quotes = []
+
+    for spread in spreads:
+        spread_quote = ql.SimpleQuote(spread.rate/100)
+        spread_quotes.append(spread_quote)
+        spread_handle = ql.QuoteHandle(spread_quote)
+        spread_handles.append(spread_handle)
+        maturity = calendar.advance(vdate, get_qlPeriod(spread.tenor))
+        spread_dates.append(maturity)
+
+    spread_curve = ql.SpreadedLinearZeroInterpolatedTermStructure(
+                            ts_handle,
+                            spread_handles,
+                            spread_dates)
+    spread_curve_handle = ql.YieldTermStructureHandle(spread_curve)
+
+    return spread_curve_handle
     
 
 
